import logging

logger = logging.getLogger(__file__)


def slurp(
        name, func, response_to_concat,
        next_token_name_in_response='NextPageToken', next_token_name_in_request='PageToken',
        **kwargs
):
    logger.info("{}: {}".format(name, kwargs))
    all_responses = []
    while True:
        logger.info(f"searching, {next_token_name_in_request}: {kwargs.get(next_token_name_in_request, 'FirstPage')}")
        response = func(**kwargs)
        all_responses += response.get(response_to_concat)
        if response.get(next_token_name_in_response) is None:
            response[response_to_concat] = all_responses
            return response
        else:
            kwargs[next_token_name_in_request] = response.get(next_token_name_in_response)



import types
import logging
import time

logger = logging.getLogger(__file__)

put_parameter_and_wait_max_retries = 10


def put_parameter_and_wait(self, Name, **kwargs):
    """
    This will call put_parameter and ensure it has been successfully put by checking it

    :param self: ssm client
    :param Name: The fully qualified name of the parameter that you want to add to the system
    :param kwargs: These args are passed through to ssm.put_parameter
    :return: ssm.get_parameter.response
    """
    new_version = self.put_parameter(Name=Name, **kwargs).get('Version')
    count = 0
    current_parameter = {
        "Parameter": {
            "Version": -1
        }
    }
    while current_parameter.get('Parameter').get('Version') < new_version:
        count += 1
        if count > put_parameter_and_wait_max_retries:
            raise Exception(f"Putting and waiting for param {Name} failed")
        time.sleep(1)
        if new_version == 1:
            try:
                current_parameter = self.get_parameter(Name=Name)
            except self.exceptions.ParameterNotFound:
                pass
        else:
            current_parameter = self.get_parameter(Name=Name)
    return current_parameter


def make_better(client):
    client.put_parameter_and_wait = types.MethodType(put_parameter_and_wait, client)
    return client



import setuptools
import os

with open(os.path.abspath(__file__).replace('setup.py', 'README.md'), "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="better-boto",
    version="0.34.0",
    author="Eamonn Faherty",
    author_email="python-packages@designandsolve.co.uk",
    description="Helpers to make using boto3 more enjoyable",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/eamonnfaherty/better-boto",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        "boto3",
        "pyyaml>=4.2b1",
    ],
)
